@@ -73,6 +73,8 @@ class vBinary:
     """Binary property values are base 64 encoded.
     """
 
+    params: Parameters
+
     def __init__(self, obj):
         self.obj = to_unicode(obj)
         self.params = Parameters(encoding='BASE64', value="BINARY")
@@ -134,11 +136,13 @@ class vBoolean(int):
         True
     """
 
+    params: Parameters
+
     BOOL_MAP = CaselessDict({'true': True, 'false': False})
 
-    def __new__(cls, *args, **kwargs):
+    def __new__(cls, *args,params={}, **kwargs):
         self = super().__new__(cls, *args, **kwargs)
-        self.params = Parameters()
+        self.params =Parameters(params)
         return self
 
     def to_ical(self):
@@ -156,11 +160,13 @@ class vText(str):
     """Simple text.
     """
 
-    def __new__(cls, value, encoding=DEFAULT_ENCODING):
+    params: Parameters
+
+    def __new__(cls, value, encoding=DEFAULT_ENCODING,params={}):
         value = to_unicode(value, encoding=encoding)
         self = super().__new__(cls, value)
         self.encoding = encoding
-        self.params = Parameters()
+        self.params=Parameters(params)
         return self
 
     def __repr__(self) -> str:
@@ -214,10 +220,12 @@ class vCalAddress(str):
 
     """
 
-    def __new__(cls, value, encoding=DEFAULT_ENCODING):
+    params: Parameters
+
+    def __new__(cls, value, encoding=DEFAULT_ENCODING,params={}):
         value = to_unicode(value, encoding=encoding)
         self = super().__new__(cls, value)
-        self.params = Parameters()
+        self.params =Parameters(params)
         return self
 
     def __repr__(self):
@@ -230,6 +238,21 @@ class vCalAddress(str):
     def from_ical(cls, ical):
         return cls(ical)
 
+    @property
+    def email(self) -> str:
+        """The email address without mailto: at the start."""
+        if self.lower().startswith("mailto:"):
+            return self[7:]
+        return str(self)
+
+    @property
+    def name(self) -> str:
+        """The CN parameter or an empty string."""
+        return self.params.get("CN", "")
+
+    @name.setter
+    def name(self, value:str):
+        self.params["CN"] = value
 
 class vFloat(float):
     """Float
@@ -277,9 +300,11 @@ class vFloat(float):
             -3.14
     """
 
-    def __new__(cls, *args, **kwargs):
+    params: Parameters
+
+    def __new__(cls,*args, params={}, **kwargs):
         self = super().__new__(cls, *args, **kwargs)
-        self.params = Parameters()
+        self.params = Parameters(params)
         return self
 
     def to_ical(self):
@@ -342,9 +367,11 @@ class vInt(int):
             432109876
     """
 
-    def __new__(cls, *args, **kwargs):
+    params: Parameters
+
+    def __new__(cls, *args,params={}, **kwargs):
         self = super().__new__(cls, *args, **kwargs)
-        self.params = Parameters()
+        self.params = Parameters(params)
         return self
 
     def to_ical(self) -> bytes:
@@ -361,6 +388,9 @@ class vInt(int):
 class vDDDLists:
     """A list of vDDDTypes values.
     """
+    
+    params: Parameters
+    dts: list
 
     def __init__(self, dt_list):
         if not hasattr(dt_list, '__iter__'):
@@ -397,12 +427,14 @@ class vDDDLists:
 
 
 class vCategory:
+    
+    params: Parameters
 
-    def __init__(self, c_list):
+    def __init__(self, c_list, params={}):
         if not hasattr(c_list, '__iter__') or isinstance(c_list, str):
             c_list = [c_list]
         self.cats = [vText(c) for c in c_list]
-        self.params = Parameters()
+        self.params = Parameters(params)
 
     def __iter__(self):
         return iter(vCategory.from_ical(self.to_ical()))
@@ -439,6 +471,8 @@ class vDDDTypes(TimeBase):
     cannot be confused, and often values can be of either types.
     So this is practical.
     """
+    
+    params: Parameters
 
     def __init__(self, dt):
         if not isinstance(dt, (datetime, date, timedelta, time, tuple)):
@@ -550,6 +584,8 @@ class vDate(TimeBase):
             >>> date.day
             14
     """
+    
+    params: Parameters
 
     def __init__(self, dt):
         if not isinstance(dt, date):
@@ -585,10 +621,12 @@ class vDatetime(TimeBase):
     created. Be aware that there are certain limitations with timezone naive
     DATE-TIME components in the icalendar standard.
     """
+    
+    params: Parameters
 
-    def __init__(self, dt):
+    def __init__(self, dt, params={}):
         self.dt = dt
-        self.params = Parameters()
+        self.params = Parameters(params)
 
     def to_ical(self):
         dt = self.dt
@@ -720,12 +758,14 @@ class vDuration(TimeBase):
             >>> duration
             datetime.timedelta(days=49)
     """
+    
+    params: Parameters
 
-    def __init__(self, td):
+    def __init__(self, td,params={}):
         if not isinstance(td, timedelta):
             raise ValueError('Value MUST be a timedelta instance')
         self.td = td
-        self.params = Parameters()
+        self.params = Parameters(params)
 
     def to_ical(self):
         sign = ""
@@ -842,6 +882,8 @@ class vPeriod(TimeBase):
             >>> period = vPeriod.from_ical('19970101T180000Z/19970102T070000Z')
             >>> period = vPeriod.from_ical('19970101T180000Z/PT5H30M')
     """
+    
+    params: Parameters
 
     def __init__(self, per):
         start, end_or_duration = per
@@ -940,11 +982,13 @@ class vWeekday(str):
         ;FRIDAY, and SATURDAY days of the week.
 
     """
+    params: Parameters
+
     week_days = CaselessDict({
         "SU": 0, "MO": 1, "TU": 2, "WE": 3, "TH": 4, "FR": 5, "SA": 6,
     })
 
-    def __new__(cls, value, encoding=DEFAULT_ENCODING):
+    def __new__(cls, value, encoding=DEFAULT_ENCODING,params={}):
         value = to_unicode(value, encoding=encoding)
         self = super().__new__(cls, value)
         match = WEEKDAY_RULE.match(self)
@@ -960,7 +1004,7 @@ class vWeekday(str):
         self.relative = relative and int(relative) or None
         if sign == '-' and self.relative:
             self.relative *= -1
-        self.params = Parameters()
+        self.params = Parameters(params)
         return self
 
     def to_ical(self):
@@ -977,6 +1021,8 @@ class vWeekday(str):
 class vFrequency(str):
     """A simple class that catches illegal values.
     """
+    
+    params: Parameters
 
     frequencies = CaselessDict({
         "SECONDLY": "SECONDLY",
@@ -988,12 +1034,12 @@ class vFrequency(str):
         "YEARLY": "YEARLY",
     })
 
-    def __new__(cls, value, encoding=DEFAULT_ENCODING):
+    def __new__(cls, value, encoding=DEFAULT_ENCODING, params={}):
         value = to_unicode(value, encoding=encoding)
         self = super().__new__(cls, value)
         if self not in vFrequency.frequencies:
             raise ValueError(f'Expected frequency, got: {self}')
-        self.params = Parameters()
+        self.params = Parameters(params)
         return self
 
     def to_ical(self):
@@ -1034,7 +1080,10 @@ class vMonth(int):
            xsd:string
         }
     """
-    def __new__(cls, month:Union[str, int]):
+        
+    params: Parameters
+
+    def __new__(cls, month:Union[str, int], params={}):
         if isinstance(month, vMonth):
             return cls(month.to_ical().decode())
         if isinstance(month, str):
@@ -1051,7 +1100,7 @@ class vMonth(int):
             month_index = int(month)
         self = super().__new__(cls, month_index)
         self.leap = leap
-        self.params = Parameters()
+        self.params = Parameters(params)
         return self
 
     def to_ical(self) -> bytes:
@@ -1168,6 +1217,8 @@ class vRecur(CaselessDict):
         >>> rrule
         vRecur({'FREQ': ['DAILY'], 'COUNT': [10]})
     """
+    
+    params: Parameters
 
     frequencies = ["SECONDLY", "MINUTELY", "HOURLY", "DAILY", "WEEKLY",
                    "MONTHLY", "YEARLY"]
@@ -1198,12 +1249,12 @@ class vRecur(CaselessDict):
         'SKIP': vSkip,
     })
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args,params={}, **kwargs):
         for k, v in kwargs.items():
             if not isinstance(v, SEQUENCE_TYPES):
                 kwargs[k] = [v]
         super().__init__(*args, **kwargs)
-        self.params = Parameters()
+        self.params = Parameters(params)
 
     def to_ical(self):
         result = []
@@ -1423,11 +1474,13 @@ class vUri(str):
                 >>> uri
                 'http://example.com/my-report.txt'
     """
+    
+    params: Parameters
 
-    def __new__(cls, value, encoding=DEFAULT_ENCODING):
+    def __new__(cls, value, encoding=DEFAULT_ENCODING, params={}):
         value = to_unicode(value, encoding=encoding)
         self = super().__new__(cls, value)
-        self.params = Parameters()
+        self.params = Parameters(params)
         return self
 
     def to_ical(self):
@@ -1499,8 +1552,10 @@ class vGeo:
             >>> event['GEO']
             vGeo((37.386013, -122.082932))
     """
+    
+    params: Parameters
 
-    def __init__(self, geo: tuple[float|str|int, float|str|int]):
+    def __init__(self, geo: tuple[float|str|int, float|str|int], params={}):
         """Create a new vGeo from a tuple of (latitude, longitude).
 
         Raises:
@@ -1515,7 +1570,7 @@ class vGeo:
                              "latitude and longitude") from e
         self.latitude = latitude
         self.longitude = longitude
-        self.params = Parameters()
+        self.params = Parameters(params)
 
     def to_ical(self):
         return f"{self.latitude};{self.longitude}"
@@ -1582,6 +1637,8 @@ class vUTCOffset:
             >>> utc_offset
             datetime.timedelta(seconds=3600)
     """
+    
+    params: Parameters
 
     ignore_exceptions = False  # if True, and we cannot parse this
 
@@ -1589,11 +1646,11 @@ class vUTCOffset:
     # it, rather than let the exception
     # propagate upwards
 
-    def __init__(self, td):
+    def __init__(self, td, params={}):
         if not isinstance(td, timedelta):
             raise ValueError('Offset value MUST be a timedelta instance')
         self.td = td
-        self.params = Parameters()
+        self.params = Parameters(params)
 
     def to_ical(self):
 
@@ -1651,11 +1708,13 @@ class vInline(str):
     has parameters. Conversion of inline values are handled by the Component
     class, so no further processing is needed.
     """
+    
+    params: Parameters
 
-    def __new__(cls, value, encoding=DEFAULT_ENCODING):
+    def __new__(cls, value, encoding=DEFAULT_ENCODING, params={}):
         value = to_unicode(value, encoding=encoding)
         self = super().__new__(cls, value)
-        self.params = Parameters()
+        self.params = Parameters(params)
         return self
 
     def to_ical(self):
